summary.localmoransad.
Values of local Moran's Ii agree with those from localmoran(),
but in that function, the standard deviate - here the Saddlepoint
approximation - is based on the randomisation assumption.localmoran.sad(model, select, nb, glist=NULL, style="W", zero.policy=FALSE,
alternative="greater", spChk=NULL, save.Vi=FALSE,
tol = .Machine$double.eps^0.5, maxiter = 1000, tol.bounds=0.0001)
as.data.frame.localmoransad(x, row.names=NULL, optional=FALSE)
print.localmoransad(x, ...)
summary.localmoransad(object, ...)
print.summary.localmoransad(x, ...)
listw2star(listw, ireg, style, n, D, a, zero.policy=FALSE)lm returned by lm (assuming no global spatial autocorrelation), or an object of class sarlm returned by a spatial simultaneous autoregressive model fit (assuming global spatial autocorrelation reprnbget.spChkOption()unirootunirootunirootas.data.frame.localmoransad;
row names assigned from localmoransad objectas.data.frame.localmoransad;
row names assigned from localmoransad objectlistw object created for example by nb2listwlocalmoransad containing "select" lists, each with
class moransad with the following components:If a histogram of the probability values of the saddlepoint estimate for the assumption of global independence is not approximately flat, the assumption is probably unjustified, and re-estimation with global dependence is recommended.
No n by n matrices are needed at any point for the test assuming no global dependence, the star-shaped weights matrices being handled as listw lists. When the test is made on residuals from a spatial regression, taking a global process into account. n by n matrices are necessary, and memory constraints may be reached for large lattices.
localmoran, lm.morantest,
lm.morantest.sad, errorsarlmdata(eire)
e.lm <- lm(OWNCONS ~ ROADACC, data=eire.df)
e.locmor <- summary(localmoran.sad(e.lm, eire.nb, select=1:nrow(eire.df)))
e.locmor
mean(e.locmor[,1])
lm.morantest(e.lm, nb2listw(eire.nb))
hist(e.locmor[,"Pr. (Sad)"])
e.errorsar <- errorsarlm(OWNCONS ~ ROADACC, data=eire.df,
listw=nb2listw(eire.nb))
e.errorsar
e.clocmor <- summary(localmoran.sad(e.errorsar, eire.nb, select=1:nrow(eire.df)))
e.clocmor
hist(e.clocmor[,"Pr. (Sad)"])Run the code above in your browser using DataLab